"use client";

import React, { useEffect, useState } from 'react';
import { FaStar } from 'react-icons/fa';
import Link from 'next/link';

interface CompanyPageProps {
  companyId: number;
}

interface Company {
  id: number;
  name: string;
  logo_path: string;
}

interface MediaItem {
  id: number;
  title?: string;
  name?: string;
  poster_path: string | null;
  vote_average: number | null;
  media_type: string; // Can be 'movie' or 'tv'
}

const CompanyPage: React.FC<CompanyPageProps> = ({ companyId }) => {
  const [company, setCompany] = useState<Company | null>(null);
  const [mediaItems, setMediaItems] = useState<MediaItem[]>([]);
  const [filteredItems, setFilteredItems] = useState<MediaItem[]>([]);
  const [searchQuery, setSearchQuery] = useState("");
  const [itemsToShow, setItemsToShow] = useState(40); // Default for PC

  useEffect(() => {
    const calculateItemsToShow = () => {
      const screenWidth = window.innerWidth;
      if (screenWidth >= 1024) {
        setItemsToShow(40); // 40 items for PC
      } else {
        setItemsToShow(21); // 21 items for mobile
      }
    };

    calculateItemsToShow();
    window.addEventListener('resize', calculateItemsToShow);

    return () => {
      window.removeEventListener('resize', calculateItemsToShow);
    };
  }, []);

  useEffect(() => {
    const fetchCompany = async () => {
      try {
        const response = await fetch(
          `https://api.themoviedb.org/3/company/${companyId}?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}`
        );
        const data = await response.json();
        setCompany(data);
      } catch (error) {
        console.error('Failed to fetch company data:', error);
      }
    };

    const fetchInitialMediaItems = async () => {
      try {
        const movieResponse = await fetch(
          `https://api.themoviedb.org/3/discover/movie?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}&with_companies=${companyId}&page=1`
        );
        const movieData = await movieResponse.json();

        const tvResponse = await fetch(
          `https://api.themoviedb.org/3/discover/tv?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}&with_companies=${companyId}&page=1`
        );
        const tvData = await tvResponse.json();

        const combinedItems = [
          ...movieData.results.slice(0, itemsToShow / 2).map((item: any) => ({ ...item, media_type: "movie" })),
          ...tvData.results.slice(0, itemsToShow / 2).map((item: any) => ({ ...item, media_type: "tv" }))
        ];

        setMediaItems(combinedItems);
        setFilteredItems(combinedItems);
      } catch (error) {
        console.error('Failed to fetch media items:', error);
      }
    };

    fetchCompany();
    fetchInitialMediaItems();
  }, [companyId, itemsToShow]);

  const fetchMoreMediaItems = async (query: string) => {
    try {
      const movieResponse = await fetch(
        `https://api.themoviedb.org/3/search/movie?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}&with_companies=${companyId}&query=${query}`
      );
      const movieData = await movieResponse.json();

      const tvResponse = await fetch(
        `https://api.themoviedb.org/3/search/tv?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}&with_companies=${companyId}&query=${query}`
      );
      const tvData = await tvResponse.json();

      const combinedItems = [
        ...movieData.results.map((item: any) => ({ ...item, media_type: "movie" })),
        ...tvData.results.map((item: any) => ({ ...item, media_type: "tv" }))
      ];

      setFilteredItems(combinedItems.slice(0, itemsToShow));
    } catch (error) {
      console.error('Failed to fetch filtered media items:', error);
    }
  };

  useEffect(() => {
    if (searchQuery.length > 0) {
      fetchMoreMediaItems(searchQuery);
    } else {
      setFilteredItems(mediaItems);
    }
  }, [searchQuery, mediaItems, itemsToShow]);

  const handleSearch = (e: React.ChangeEvent<HTMLInputElement>) => {
    setSearchQuery(e.target.value);
  };

  return (
    <div className="relative mt-0 md:mt-24">
      {company && (
        <div className="relative mb-8 md:mb-12">
          <div className="relative bg-white bg-opacity-90 p-4 flex justify-center items-center h-64 md:h-72">
            <div className="absolute bottom-0 w-full h-16 bg-gradient-to-b from-transparent to-black"></div>
            <img
              src={`https://image.tmdb.org/t/p/original${company.logo_path}`}
              alt={company.name}
              className="h-24 relative z-10"
            />
          </div>

          <div className="absolute bottom-0 left-1/2 transform -translate-x-1/2 translate-y-1/2 w-4/5">
            <input
              type="text"
              value={searchQuery}
              onChange={handleSearch}
              placeholder={`Search for movies or TV series from ${company?.name}`}
              className="w-full bg-black text-white p-4 rounded-lg border-2 border-red-600 focus:outline-none transition-all duration-300 ease-in-out"
            />
          </div>
        </div>
      )}

      <div className="mt-12 grid grid-cols-3 sm:grid-cols-3 md:grid-cols-5 lg:grid-cols-8 gap-4 px-4 animate-fadeIn">
        {filteredItems.map((item) => {
          const slug = `${item.id}-${item.name || item.title}`.toLowerCase().replace(/ /g, '-');
          const url = item.media_type === 'movie' ? `/watch/movie/?slug=${slug}` : `/watch/tv/?slug=${slug}`;

          return (
            <Link key={item.id} href={url} passHref>
              <div
                className="relative bg-cover bg-center rounded-lg overflow-hidden shadow-lg hover:scale-105 transition-transform duration-300 ease-in-out cursor-pointer animate-shuffle"
                style={{
                  backgroundImage: item.poster_path ? `url(https://image.tmdb.org/t/p/w500${item.poster_path})` : 'url(/fallback-image.jpg)', // Fallback image if no poster
                  paddingBottom: '150%',
                }}
              >
                <div className="absolute top-2 right-2 bg-black bg-opacity-70 text-yellow-400 text-xs px-2 py-1 rounded flex items-center">
                  <FaStar className="mr-1" />
                  {item.vote_average ? item.vote_average.toFixed(1) : 'N/A'}
                </div>
              </div>
            </Link>
          );
        })}
      </div>

      <div className="hidden md:block h-12"></div>
      <div className="block md:hidden h-24"></div> {/* Space to avoid overlap with mobile navbar */}

      <style jsx>{`
        .animate-fadeIn {
          animation: fadeIn 1s ease-in-out;
        }

        .animate-shuffle {
          animation: shuffle 0.5s ease-in-out;
        }

        @keyframes fadeIn {
          from {
            opacity: 0;
            transform: translateY(20px);
          }
          to {
            opacity: 1;
            transform: translateY(0);
          }
        }

        @keyframes shuffle {
          from {
            opacity: 0.5;
            transform: scale(0.95);
          to {
            opacity: 1;
            transform: scale(1);
          }
        }
      `}</style>
    </div>
  );
};

export default CompanyPage;
